package com.qmth.teachcloud.report.business.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.qmth.teachcloud.common.bean.params.TBExamCourseDeleteParams;
import com.qmth.teachcloud.common.enums.ExceptionResultEnum;
import com.qmth.teachcloud.report.business.entity.TBCommonLevelConfig;
import com.qmth.teachcloud.report.business.entity.TBCommonRankLevelConfig;
import com.qmth.teachcloud.report.business.entity.TBDimension;
import com.qmth.teachcloud.report.business.service.*;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * @Description: 分析课程物理删除服务实现类
 * @Author: CaoZixuan
 * @Date: 2022-07-05
 */
@Service
public class TBExamCourseDeleteServiceImpl implements TBExamCourseDeleteService {
    @Resource
    TBCommonLevelConfigService tbCommonLevelConfigService;
    @Resource
    TBCommonRankLevelConfigService tbCommonRankLevelConfigService;
    @Resource
    TBDimensionService tbDimensionService;
    @Resource
    TBExamCourseService tbExamCourseService;
    @Resource
    TBExamStudentService tbExamStudentService;
    @Resource
    TBModuleConfigService tbModuleConfigService;
    @Resource
    TBModuleProficiencyService tbModuleProficiencyService;



    @Transactional(rollbackFor = Exception.class)
    @Override
    public void deleteBasicTableData(Long schoolId, Long examId, String courseCode) {
        if (tbExamCourseService.verifyExamCourseCantDelete(schoolId,examId,courseCode)){
            throw ExceptionResultEnum.ERROR.exception("考试id为【" + examId + "】，课程编号为【" + courseCode + "】的分析课程当前不能被删除");
        }
        // 基础且无关联表删除
        tbCommonLevelConfigService.remove(new QueryWrapper<TBCommonLevelConfig>()
                .lambda()
                .eq(TBCommonLevelConfig::getExamId,examId)
                .eq(TBCommonLevelConfig::getCourseCode,courseCode));
        tbCommonRankLevelConfigService.remove(new QueryWrapper<TBCommonRankLevelConfig>()
                .lambda()
                .eq(TBCommonRankLevelConfig::getExamId,examId)
                .eq(TBCommonRankLevelConfig::getCourseCode,courseCode));
        tbDimensionService.remove(new QueryWrapper<TBDimension>()
                .lambda()
                .eq(TBDimension::getExamId,examId)
                .eq(TBDimension::getCourseCode,courseCode));
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void deleteAnalyzeTableData(Long schoolId, Long examId, String courseCode) {

    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void repeatCalculateTotalTableData(Long schoolId, Long examId, String courseCode) {

    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void deleteTBExamCourse(List<TBExamCourseDeleteParams> tbExamCourseDeleteParamsList) {

    }
}
